@@ -26,9 +26,15 @@ class Video(TeamTVObject):
     def skip_transcoding(self):
         return self._skip_transcoding
 
+    @property
+    def livestream(self):
+        return self._livestream
+
     @property
     def is_upload_completed(self):
-        return all(part["state"] != "new" for part in self._parts)
+        return (
+            all(part["state"] != "new" for part in self._parts) and len(self._parts) > 0
+        )
 
     def __repr__(self):
         return f"<Video video_id={self.video_id} state={self.state}>"
@@ -39,6 +45,7 @@ class Video(TeamTVObject):
         self._media_url = attributes.get("mediaUrl")
         self._state = attributes["state"]
         self._tags = attributes.get("tags", {})
+        self._livestream = attributes.get("livestream", {})
         self._skip_transcoding = attributes.get("skipTranscoding", False)
 
         super()._use_attributes(attributes)
